@@ -6,7 +6,7 @@ import marshal
 
 import tokyo.cabinet as tc
 
-from fields import *
+from properties import *
 
 
 class class_cached_property(object):
@@ -39,7 +39,7 @@ class Model(object):
         else:
             self._raw_data = {}
             for prop_name, value in kwargs.iteritems():
-                if prop_name not in self._fields:
+                if prop_name not in self._properties:
                     raise Error('Unknown field "%s" in model "%s"' % (
                         prop_name, self.__class__.__name__))
                 setattr(self, prop_name, value)
@@ -78,7 +78,7 @@ class Model(object):
             raise Error('set __filename__ in model "%s"' % cls.__name__)
         db = tc.TDB()
         db.open(cls.__filename__, tc.HDBOWRITER | tc.HDBOCREAT)
-        for prop in (cls.__dict__[n] for n in cls._fields):
+        for prop in (cls.__dict__[n] for n in cls._properties):
             if prop.index:
                 if not prop.INDEX:
                     raise Error('field "%s" is not indexed' % prop.__class__.__name__)
@@ -91,15 +91,15 @@ class Model(object):
         return db
     
     @class_cached_property
-    def _fields(cls):
+    def _properties(cls):
         '''
         {prop_attr_name: save_key_name}
         '''
         ret = {}
         for k, prop in cls.__dict__.items():
-            if isinstance(prop, KeyField):
+            if isinstance(prop, KeyProperty):
                 ret[k] = None
-            if issubclass(prop.__class__, BaseField):
+            if issubclass(prop.__class__, BaseProperty):
                 if not prop.key:
                     prop.key = k
                 if prop.key in ret.values():
@@ -109,7 +109,7 @@ class Model(object):
         
     def __unicode__(self):
         items = []
-        for k in ['key'] + self._fields.keys():
+        for k in ['key'] + self._properties.keys():
             v = getattr(self, k)
             if isinstance(v, str):
                 v = "'%s'" % v
